def test_pass():
    pass


def test_fail():
    raise Exception("fail")


def test_failx2():
    raise Exception("fail")
